@@ -97,7 +97,6 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
 
     QBoxLayout *top = new QVBoxLayout(this);
     top->setMargin(0);
-    top->setSpacing(KDialog::spacingHint());
 
     tabwidget = new QTabWidget(this);
     top->addWidget(tabwidget);
@@ -199,14 +198,10 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
     tabwidget->addTab(advancedTab, i18n("Advanced"));
 
     QFormLayout *lay = new QFormLayout(advancedTab);
-    lay->setMargin(KDialog::marginHint());
-    lay->setSpacing(KDialog::spacingHint());
 
     accel = new KDoubleNumInput(0.1, 20, 2, advancedTab, 0.1, 1);
     accel->setSuffix(i18n(" x"));
-    QLabel* lbl = new QLabel(i18n("Pointer acceleration:"), advancedTab);
-    lbl->setBuddy(accel);
-    lay->addRow(lbl, accel);
+    lay->addRow(i18n("Pointer acceleration:"), accel);
     connect(accel, SIGNAL(valueChanged(double)), this, SLOT(changed()));
 
     wtstr = i18n("<p>This option allows you to change the relationship"
@@ -224,9 +219,7 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
     thresh = new KIntNumInput(20, advancedTab);
     thresh->setRange(0,20,1);
     thresh->setSteps(1,1);
-    lbl = new QLabel(i18n("Pointer threshold:"), advancedTab);
-    lbl->setBuddy(thresh);
-    lay->addRow(lbl, thresh);
+    lay->addRow(i18n("Pointer threshold:"), thresh);
     connect(thresh, SIGNAL(valueChanged(int)), this, SLOT(changed()));
     connect(thresh, SIGNAL(valueChanged(int)), this, SLOT(slotThreshChanged(int)));
     slotThreshChanged(thresh->value());
@@ -248,9 +241,7 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
     doubleClickInterval->setRange(0, 2000, 100);
     doubleClickInterval->setSuffix(i18n(" msec"));
     doubleClickInterval->setSteps(100, 100);
-    lbl = new QLabel(i18n("Double click interval:"), advancedTab);
-    lbl->setBuddy(doubleClickInterval);
-    lay->addRow(lbl, doubleClickInterval);
+    lay->addRow(i18n("Double click interval:"), doubleClickInterval);
     connect(doubleClickInterval, SIGNAL(valueChanged(int)), this, SLOT(changed()));
 
     wtstr = i18n("The double click interval is the maximal time"
@@ -265,9 +256,7 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
     dragStartTime->setRange(0, 2000, 100);
     dragStartTime->setSuffix(i18n(" msec"));
     dragStartTime->setSteps(100, 100);
-    lbl = new QLabel(i18n("Drag start time:"), advancedTab);
-    lbl->setBuddy(dragStartTime);
-    lay->addRow(lbl, dragStartTime);
+    lay->addRow(i18n("Drag start time:"), dragStartTime);
     connect(dragStartTime, SIGNAL(valueChanged(int)), this, SLOT(changed()));
 
     wtstr = i18n("If you click with the mouse (e.g. in a multi-line"
@@ -278,9 +267,7 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
     dragStartDist = new KIntNumInput(20, advancedTab);
     dragStartDist->setRange(1, 20, 1);
     dragStartDist->setSteps(1,1);
-    lbl = new QLabel(i18n("Drag start distance:"), advancedTab);
-    lbl->setBuddy(dragStartDist);
-    lay->addRow(lbl, dragStartDist);
+    lay->addRow(i18n("Drag start distance:"), dragStartDist);
     connect(dragStartDist, SIGNAL(valueChanged(int)), this, SLOT(changed()));
     connect(dragStartDist, SIGNAL(valueChanged(int)), this, SLOT(slotDragStartDistChanged(int)));
     slotDragStartDistChanged(dragStartDist->value());
@@ -293,9 +280,7 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
     wheelScrollLines = new KIntNumInput(3, advancedTab);
     wheelScrollLines->setRange(1, 12, 1);
     wheelScrollLines->setSteps(1,1);
-    lbl = new QLabel(i18n("Mouse wheel scrolls by:"), advancedTab);
-    lbl->setBuddy(wheelScrollLines);
-    lay->addRow(lbl, wheelScrollLines);
+    lay->addRow(i18n("Mouse wheel scrolls by:"), wheelScrollLines);
     connect(wheelScrollLines, SIGNAL(valueChanged(int)), this, SLOT(changed()));
     connect(wheelScrollLines, SIGNAL(valueChanged(int)), SLOT(slotWheelScrollLinesChanged(int)));
     slotWheelScrollLinesChanged(wheelScrollLines->value());
@@ -308,54 +293,34 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
   mouse->setObjectName("Mouse Navigation");
   tabwidget->addTab(mouse, i18n("Mouse Navigation"));
 
-  QBoxLayout *vbox = new QVBoxLayout(mouse);
-  vbox->setMargin(KDialog::marginHint());
-  vbox->setSpacing(KDialog::spacingHint());
-
-  QVBoxLayout *vvbox = new QVBoxLayout();
-  vbox->addItem( vvbox );
-  vvbox->setSpacing(KDialog::spacingHint());
+  QFormLayout *form = new QFormLayout(mouse);
 
   mouseKeys = new QCheckBox(i18n("&Move pointer with keyboard (using the num pad)"), mouse);
-  vvbox->addWidget(mouseKeys);
-
-  QFormLayout *form = new QFormLayout();
-  vvbox->addItem( form );
-  form->setSpacing(KDialog::spacingHint());
+  form->addRow(mouseKeys);
 
   mk_delay = new KIntNumInput(mouse);
-  mk_delay->setSuffix(i18n(" msec"));
   mk_delay->setRange(1, 1000, 50);
-  lbl = new QLabel(i18n("&Acceleration delay:"), mouse);
-  lbl->setBuddy(mk_delay);
-  form->addRow(lbl, mk_delay);
+  mk_delay->setSuffix(i18n(" msec"));
+  form->addRow(i18n("&Acceleration delay:"), mk_delay);
 
   mk_interval = new KIntNumInput(0, mouse);
-  mk_interval->setSuffix(i18n(" msec"));
   mk_interval->setRange(1, 1000, 10);
-  lbl = new QLabel(i18n("R&epeat interval:"), mouse);
-  lbl->setBuddy(mk_interval);
-  form->addRow(lbl, mk_interval);
+  mk_interval->setSuffix(i18n(" msec"));
+  form->addRow(i18n("R&epeat interval:"), mk_interval);
 
   mk_time_to_max = new KIntNumInput(0, mouse);
   mk_time_to_max->setRange(100, 10000, 200);
   mk_time_to_max->setSuffix(i18n(" msec"));
-  lbl = new QLabel(i18n("Acceleration &time:"), mouse);
-  lbl->setBuddy(mk_time_to_max);
-  form->addRow(lbl, mk_time_to_max);
+  form->addRow(i18n("Acceleration &time:"), mk_time_to_max);
 
   mk_max_speed = new KIntNumInput(0, mouse);
   mk_max_speed->setRange(1, 2000, 20);
   mk_max_speed->setSuffix(i18n(" pixel/sec"));
-  lbl = new QLabel(i18n("Ma&ximum speed:"), mouse);
-  lbl->setBuddy(mk_max_speed);
-  form->addRow(lbl, mk_max_speed);
+  form->addRow(i18n("Ma&ximum speed:"), mk_max_speed);
 
   mk_curve = new KIntNumInput(0, mouse);
   mk_curve->setRange(-1000, 1000, 100);
-  lbl = new QLabel(i18n("Acceleration &profile:"), mouse);
-  lbl->setBuddy(mk_curve);
-  form->addRow(lbl, mk_curve);
+  form->addRow(i18n("Acceleration &profile:"), mk_curve);
 
   connect(mouseKeys, SIGNAL(clicked()), this, SLOT(checkAccess()));
   connect(mouseKeys, SIGNAL(clicked()), this, SLOT(changed()));
@@ -364,8 +329,6 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
   connect(mk_time_to_max, SIGNAL(valueChanged(int)), this, SLOT(changed()));
   connect(mk_max_speed, SIGNAL(valueChanged(int)), this, SLOT(changed()));
   connect(mk_curve, SIGNAL(valueChanged(int)), this, SLOT(changed()));
-
-  vbox->addStretch();
 }
 
   settings = new MouseSettings;
@@ -374,11 +337,12 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
   // It only works if libusb is available.
 #ifdef HAVE_LIBUSB
 
+  static const
   struct device_table {
       int idVendor;
       int idProduct;
-      QString Model;
-      QString Name;
+      const char* Model;
+      const char* Name;
       int flags;
   } device_table[] = {
       { VENDOR_LOGITECH, 0xC00E, "M-BJ58", "Wheel Mouse Optical", HAS_RES },
@@ -398,7 +362,7 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
       { VENDOR_LOGITECH, 0xC50B, "967300-0403", "Cordless MX Duo Receiver", HAS_SS|HAS_CSR },
       { VENDOR_LOGITECH, 0xC50E, "M-RAG97", "MX1000 Laser Mouse", HAS_SS | HAS_CSR },
       { VENDOR_LOGITECH, 0xC702, "C-UF15", "Receiver for Cordless Presenter", HAS_CSR },
-      { 0, 0, QString(), QString(), 0 }
+      { 0, 0, 0, 0, 0 }
   };
 
   usb_init();
@@ -414,7 +378,7 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
 	      if ( (device_table[n].idVendor == dev->descriptor.idVendor) &&
 		   (device_table[n].idProduct == dev->descriptor.idProduct) ) {
 		  // OK, we have a device that appears to be one of the ones we support
-		  LogitechMouse *mouse = new LogitechMouse( dev, device_table[n].flags, this, device_table[n].Name.toLatin1() );
+		  LogitechMouse *mouse = new LogitechMouse( dev, device_table[n].flags, this, device_table[n].Name );
 		  settings->logitechMouseList.append(mouse);
 		  tabwidget->addTab( (QWidget*)mouse, device_table[n].Name );
 	      }
@@ -492,6 +456,7 @@ void MouseConfig::setHandedness(int val)
     generalTab->leftHanded->setChecked(true);
     generalTab->mousePix->setPixmap(KStandardDirs::locate("data", "kcminput/pics/mouse_lh.png"));
   }
+  settings->m_handedNeedsApply = true;
 }
 
 void MouseConfig::load()
@@ -554,7 +519,8 @@ void MouseConfig::load()
   themetab->load();
 
   checkAccess();
-  changed();
+
+  emit changed(false);
 }
 
 void MouseConfig::save()
@@ -600,8 +566,7 @@ void MouseConfig::save()
   // restart kaccess
   KToolInvocation::startServiceByDesktopName("kaccess");
 
-  KCModule::changed(false);
-
+  emit changed(false);
 }
 
 void MouseConfig::defaults()
@@ -627,6 +592,8 @@ void MouseConfig::defaults()
   mk_time_to_max->setValue(5000);
   mk_max_speed->setValue(1000);
   mk_curve->setValue(0);
+  
+  themetab->defaults();
 
   checkAccess();
 
