@@ -102,7 +102,6 @@ extern char **environ;
 # define Jmp_buf sigjmp_buf
 #endif
 
-#include <utmp.h>
 #ifdef HAVE_UTMPX
 # include <utmpx.h>
 # define STRUCTUTMP struct utmpx
@@ -113,15 +112,16 @@ extern char **environ;
 # define ENDUTENT endutxent
 # define ut_time ut_tv.tv_sec
 #else
+# include <utmp.h>
 # define STRUCTUTMP struct utmp
 # define UTMPNAME utmpname
 # define SETUTENT setutent
 # define GETUTENT getutent
 # define PUTUTLINE pututline
 # define ENDUTENT endutent
-#endif
-#ifndef HAVE_STRUCT_UTMP_UT_USER
-# define ut_user ut_name
+# ifndef HAVE_STRUCT_UTMP_UT_USER
+#  define ut_user ut_name
+# endif
 #endif
 #ifndef WTMP_FILE
 # ifdef _PATH_WTMPX
@@ -232,6 +232,9 @@ typedef struct {
 	struct cmdsock *css;  /* open connections */
 
 	char *path;           /* filename of the socket */
+#ifndef HONORS_SOCKET_PERMS
+	char *realdir;        /* real dirname of the socket */
+#endif
 	int fd;               /* fd of the socket */
 	int gid;              /* owner group of the socket */
 } CtrlRec;
@@ -560,6 +563,7 @@ int reader( int fd, void *buf, int len );
 int writer( int fd, const void *buf, int len );
 int fGets( char *buf, int max, FILE *f );
 time_t mTime( const char *fn );
+void randomStr( char *s );
 int hexToBinary( char *out, const char *in );
 void listSessions( int flags, struct display *d, void *ctx,
                    void (*emitXSess)( struct display *, struct display *, void * ),
