@@ -27,7 +27,6 @@
 
 #include <kconfig.h>
 #include <kdialog.h>
-#include <ktextedit.h>
 #include <klocale.h>
 #include <kmenu.h>
 #include <kservice.h>
@@ -107,8 +106,8 @@ void URLGrabber::setActionList( const ActionList& list )
 void URLGrabber::matchingMimeActions(const QString& clipData)
 {
     KUrl url(clipData);
-    KConfigGroup cg(KGlobal::config(), "General");
-    if(!cg.readEntry("EnableMagicMimeActions",true)) { //Secret configuration entry
+    KConfigGroup cg(KGlobal::config(), "Actions");
+    if(!cg.readEntry("EnableMagicMimeActions",true)) {
     //    kDebug() << "skipping mime magic due to configuration";
     	return;
     }
@@ -147,7 +146,7 @@ void URLGrabber::matchingMimeActions(const QString& clipData)
         mimetype = KMimeType::findByPath( "/tmp/klipper.html", 0, true /*fast mode*/ );
     }
 
-    if ( mimetype->name() != "application/octet-stream" ) {
+    if ( !mimetype->isDefault() ) {
         ClipAction* action = new ClipAction( QString(), mimetype->comment() );
         KService::List lst = KMimeTypeTrader::self()->query( mimetype->name(), "Application" );
         foreach( const KService::Ptr &service, lst ) {
@@ -189,7 +188,7 @@ void URLGrabber::actionMenu( bool automatically_invoked )
 {
     QString text(m_myClipItem->text());
     if (m_trimmed) {
-        text.trimmed();
+        text = text.trimmed();
     }
     ActionList matchingActionsList = matchingActions( text, automatically_invoked );
 
@@ -242,10 +241,6 @@ void URLGrabber::actionMenu( bool automatically_invoked )
             m_myMenu->addAction(disableAction);
         }
         m_myMenu->addSeparator();
-        // add an edit-possibility
-        QAction *editAction = new QAction(KIcon("document-properties"), i18n("&Edit Contents..."), this);
-        connect(editAction, SIGNAL(triggered()), SLOT(editData()));
-        m_myMenu->addAction(editAction);
 
         QAction *cancelAction = new QAction(KIcon("dialog-cancel"), i18n("&Cancel"), this);
         connect(cancelAction, SIGNAL(triggered()), m_myMenu, SLOT(hide()));
@@ -293,7 +288,7 @@ void URLGrabber::execute( const ClipAction *action, int cmdIdx ) const
     if ( command.isEnabled ) {
         QString text(m_myClipItem->text());
         if (m_trimmed) {
-            text.trimmed();
+            text = text.trimmed();
         }
         ClipCommandProcess* proc = new ClipCommandProcess(*action, command, text, m_history, m_myClipItem);
         if (proc->program().isEmpty()) {
@@ -305,40 +300,6 @@ void URLGrabber::execute( const ClipAction *action, int cmdIdx ) const
     }
 }
 
-
-void URLGrabber::editData()
-{
-    if (!m_myClipItem) {
-        return;
-    }
-    m_myPopupKillTimer->stop();
-    KDialog *dlg = new KDialog( 0 );
-    dlg->setModal( true );
-    dlg->setCaption( i18n("Edit Contents") );
-    dlg->setButtons( KDialog::Ok | KDialog::Cancel );
-
-    KTextEdit *edit = new KTextEdit( dlg );
-    edit->setText( m_myClipItem->text() );
-    edit->setFocus();
-    edit->setMinimumSize( 300, 40 );
-    dlg->setMainWidget( edit );
-    dlg->adjustSize();
-
-    if ( dlg->exec() == KDialog::Accepted ) {
-        QString text = edit->toPlainText();
-        m_history->remove( m_myClipItem );
-        m_history->insert( new HistoryStringItem(text) );
-        QTimer::singleShot( 0, this, SLOT( slotActionMenu() ) );
-    }
-    else
-    {
-        m_myMenu->deleteLater();
-        m_myMenu = 0;
-    }
-    delete dlg;
-}
-
-
 void URLGrabber::loadSettings()
 {
     m_trimmed = KlipperSettings::stripWhiteSpace();
@@ -377,6 +338,7 @@ void URLGrabber::saveSettings() const
 // digged a little bit in netwm.cpp
 bool URLGrabber::isAvoidedWindow() const
 {
+#ifdef Q_WS_X11
     Display *d = QX11Info::display();
     static Atom wm_class = XInternAtom( d, "WM_CLASS", true );
     static Atom active_window = XInternAtom( d, "_NET_ACTIVE_WINDOW", true );
@@ -415,6 +377,9 @@ bool URLGrabber::isAvoidedWindow() const
     }
 
     return ret;
+#else
+    return false;
+#endif
 }
 
 
