@@ -23,6 +23,8 @@
 #include <QBoxLayout>
 #include <QDesktopWidget>
 #include <QLabel>
+#include <QTimer>
+#include <QShortcut>
 #include <QToolButton>
 
 #include <KAction>
@@ -48,12 +50,14 @@ QsDialog::QsDialog(Plasma::RunnerManager *runnerManager, QWidget *parent)
 
     QHBoxLayout *hLayout = new QHBoxLayout();
 
-    QToolButton *m_configButton = new QToolButton(w);
+    m_configButton = new QToolButton(w);
     m_configButton->setText(i18n("Settings"));
     m_configButton->setToolTip(i18n("Settings"));
     m_configButton->setIcon(m_iconSvg->pixmap("configure"));
     connect(m_configButton, SIGNAL(clicked()), SLOT(showConfigDialog()));
 
+    m_singleRunnerIcon = new QLabel(w);
+
     QLabel *label = new QLabel(w);
     label->setText("<b>QuickSand</b>");
 
@@ -65,6 +69,7 @@ QsDialog::QsDialog(Plasma::RunnerManager *runnerManager, QWidget *parent)
     connect(m_closeButton, SIGNAL(clicked(bool)), this, SLOT(close()));
 
     hLayout->addWidget(m_configButton);
+    hLayout->addWidget(m_singleRunnerIcon);
     hLayout->addStretch();
     hLayout->addWidget(label);
     hLayout->addStretch();
@@ -80,7 +85,7 @@ QsDialog::QsDialog(Plasma::RunnerManager *runnerManager, QWidget *parent)
     m_actionView = new QuickSand::QsMatchView(w);
     layout->addWidget(m_actionView);
     m_actionView->setTitle(i18n("Actions"));
-    m_actionView->setItemCountSuffix(i18n("actions"));
+    m_actionView->setCountingActions(true);
     m_actionView->hide();
 
     Plasma::Theme *theme = Plasma::Theme::defaultTheme();
@@ -112,6 +117,8 @@ QsDialog::QsDialog(Plasma::RunnerManager *runnerManager, QWidget *parent)
     m_matchView->setFocus();
 
     m_newQuery = true;
+    
+    new QShortcut(QKeySequence(Qt::Key_Escape), this, SLOT(close()));
 }
 
 QsDialog::~QsDialog()
@@ -121,15 +128,48 @@ QsDialog::~QsDialog()
 void QsDialog::clearHistory()
 {}
 
+void QsDialog::setConfigWidget(QWidget *w)
+{
+    m_matchView->hide();
+    QVBoxLayout *layout = static_cast<QVBoxLayout*>(mainWidget()->layout());
+    layout->addWidget(w);
+    adjustSize();
+    connect(w, SIGNAL(destroyed(QObject*)), this, SLOT(configWidgetDestroyed()));
+}
+
+void QsDialog::configWidgetDestroyed()
+{
+    QTimer::singleShot(0, this, SLOT(cleanupAfterConfigWidget()));
+}
+
+void QsDialog::cleanupAfterConfigWidget()
+{
+    m_matchView->show();
+    m_matchView->setFocus();
+    adjustSize();
+}
+
+void QsDialog::adjustInterface()
+{
+    if (m_runnerManager->singleModeRunner()) {
+        m_singleRunnerIcon->setPixmap(m_runnerManager->singleModeRunner()->icon().pixmap( QSize( 22, 22 )) );
+        m_singleRunnerIcon->show();
+        m_configButton->hide();
+    } else {
+        m_singleRunnerIcon->hide();
+        m_configButton->show();
+    }
+}
+
 void QsDialog::display(const QString &term)
 {
     KWindowSystem::setOnDesktop(winId(), KWindowSystem::currentDesktop());
 
+    adjustInterface();
     m_matchView->reset();
     m_actionView->reset();
     m_actionView->hide();
     adjustSize();
-    show();
     m_matchView->setFocus();
 
     int screen = 0;
@@ -137,14 +177,10 @@ void QsDialog::display(const QString &term)
         screen = QApplication::desktop()->screenNumber(QCursor::pos());
     }
 
-    //KDialog::centerOnScreen(this, screen); // For some reason, this isn't working
-    QDesktopWidget *desktop = QApplication::desktop();
-    QRect r = desktop->screenGeometry(screen);
-    move(r.left() + (r.width() / 2) - (width() / 2),
-         r.top() + (r.height() / 2) - (height() / 2));
-
+    //positionOnScreen will call QWidget::show anyways so we don't need to call it here
+    positionOnScreen();
     KWindowSystem::forceActiveWindow(winId());
-    if (term.isEmpty()) {
+    if (term.isEmpty() && !m_runnerManager->singleMode()) {
         m_matchView->setTitle(QString());
     } else {
         m_matchView->setTitle(term);
@@ -154,11 +190,12 @@ void QsDialog::display(const QString &term)
 
 void QsDialog::launchQuery(const QString &query)
 {
-    if (query.isEmpty()) {
+    if (query.isEmpty() && !m_runnerManager->singleMode()) {
         m_matchView->reset();
     } else {
         m_matchView->showLoading();
     }
+
     m_runnerManager->launchQuery(query);
     m_newQuery = true;
 }
