@@ -44,7 +44,9 @@ enum ButtonType {
     AboveButton,
     BelowButton,
     ShadeButton,
-    NumButtons
+    NumButtons,
+    ItemCloseButton=100, // Close only one tab
+    ItemMenuButton // shows the window menu for one tab
 };
 
 class KCommonDecorationButton;
@@ -119,7 +121,11 @@ class KWIN_EXPORT KCommonDecoration : public QObject, public KDecorationDefines
             LM_ButtonHeight,
             LM_ButtonSpacing,
             LM_ExplicitButtonSpacer,
-            LM_ButtonMarginTop
+            LM_ButtonMarginTop,
+            LM_OuterPaddingLeft,   ///< @since 4.3
+            LM_OuterPaddingTop,    ///< @since 4.3
+            LM_OuterPaddingRight,  ///< @since 4.3
+            LM_OuterPaddingBottom ///< @since 4.4
         };
 
         enum DecorationBehaviour
@@ -227,6 +233,22 @@ class KWIN_EXPORT KCommonDecoration : public QObject, public KDecorationDefines
          */
         QRect titleRect() const;
 
+        /**
+         * Returns the rectangle within the decoration that should be transparent.
+         *
+         * Usually this is the rectangle occupied by the client window,
+         * but a smaller rectangle may be returned if the client has specified
+         * that the window decoration should extend below the client area.
+         *
+         * If the client has requested that the decoration should cover the whole
+         * client area, a null rectangle is returned.
+         *
+         * The returned rectangle is never larger than the client area.
+         *
+         * @since 4.4
+         */
+        QRect transparentRect() const;
+
     public:
         /**
          * Handles widget and layout creation, call the base implementation when subclassing this member.
@@ -333,6 +355,10 @@ class KWIN_EXPORT KCommonDecoration : public QObject, public KDecorationDefines
         const KDecoration* decoration() const;
         KDecoration* decoration();
 
+    private Q_SLOTS:
+        /* look out for buttons that have been destroyed. */
+        void objDestroyed(QObject *obj);
+
     private:
         void resetLayout();
 
@@ -369,14 +395,23 @@ class KWIN_EXPORT KCommonDecorationUnstable
     public:
         KCommonDecorationUnstable(KDecorationBridge* bridge, KDecorationFactory* factory);
         virtual ~KCommonDecorationUnstable();
-        virtual QList<QRect> shadowQuads( ShadowType type ) const;
-        virtual double shadowOpacity( ShadowType type ) const;
-        virtual double shadowBrightness( ShadowType type ) const;
-        virtual double shadowSaturation( ShadowType type ) const;
-        void repaintShadow();
         bool compositingActive() const;
-        bool shadowsActive() const;
-        double opacity() const;
+
+        // Window tabbing
+        bool isClientGroupActive();
+        QList< ClientGroupItem > clientGroupItems() const;
+        long itemId( int index );
+        int visibleClientGroupItem();
+        void setVisibleClientGroupItem( int index );
+        void moveItemInClientGroup( int index, int before );
+        void moveItemToClientGroup( long itemId, int before = -1 );
+        void removeFromClientGroup( int index, const QRect& newGeom = QRect() );
+        void closeClientGroupItem( int index );
+        void closeAllInClientGroup();
+        void displayClientMenu( int index, const QPoint& pos );
+
+        WindowOperation buttonToWindowOperation( Qt::MouseButtons button );
+        virtual bool eventFilter( QObject* o, QEvent* e );
     };
 
 /**
