@@ -134,9 +134,10 @@ bool KDecorationPlugins::loadPlugin( QString nameStr )
 	return true;
 
     // Try loading the requested plugin
-    library = KLibLoader::self()->library(path);
+    library = new KLibrary(path);
 
     // If that fails, fall back to the default plugin
+trydefaultlib:
     if (!library)
         {
 	kDebug(1212) << " could not load library, try default plugin again";
@@ -145,7 +146,7 @@ bool KDecorationPlugins::loadPlugin( QString nameStr )
 	    return true;
         path = KLibLoader::findLibrary(nameStr);
 	if (!path.isEmpty())
-            library = KLibLoader::self()->library(path);
+            library = new KLibrary(path);
         }
 
     if (!library)
@@ -162,6 +163,13 @@ bool KDecorationPlugins::loadPlugin( QString nameStr )
 
     if(!create_ptr)
         {
+        if( nameStr != defaultPlugin )
+            {
+            kDebug(1212) << i18n( "The library %1 is not a KWin plugin.", path );
+            library->unload();
+            library = NULL;
+            goto trydefaultlib;
+            }
         error( i18n( "The library %1 is not a KWin plugin.", path ));
         library->unload();
         return false;
