@@ -114,7 +114,7 @@ void Effect::reconfigure( ReconfigureFlags )
     {
     }
 
-const void* Effect::proxy() const
+void* Effect::proxy()
     {
     return NULL;
     }
@@ -123,6 +123,10 @@ void Effect::windowUserMovedResized( EffectWindow* , bool, bool )
     {
     }
 
+void Effect::windowMoveResizeGeometryUpdate( EffectWindow* , const QRect& )
+    {
+    }
+
 void Effect::windowOpacityChanged( EffectWindow*, double )
     {
     }
@@ -151,6 +155,18 @@ void Effect::windowUnminimized( EffectWindow* )
     {
     }
 
+void Effect::clientGroupItemSwitched( EffectWindow*, EffectWindow* )
+    {
+    }
+
+void Effect::clientGroupItemAdded( EffectWindow*, EffectWindow* )
+    {
+    }
+
+void Effect::clientGroupItemRemoved( EffectWindow*, EffectWindow* )
+    {
+    }
+
 void Effect::windowInputMouseEvent( Window, QEvent* )
     {
     }
@@ -186,6 +202,11 @@ void Effect::tabBoxClosed()
 void Effect::tabBoxUpdated()
     {
     }
+
+void Effect::tabBoxKeyEvent( QKeyEvent* )
+    {
+    }
+
 bool Effect::borderActivated( ElectricBorder )
     {
     return false;
@@ -960,13 +981,13 @@ QRect PaintClipper::Iterator::boundingRect() const
  TimeLine
 ***************************************************************/
 
-TimeLine::TimeLine(int duration)
+TimeLine::TimeLine(const int duration)
     {
     m_Time = 0;
     m_Duration = duration;
     m_TimeLine = new QTimeLine(m_Duration ? m_Duration : 1); // (avoid QTimeLine warning)
     m_TimeLine->setFrameRange(0, m_Duration);
-    m_TimeLine->setCurveShape(QTimeLine::EaseInCurve);
+    setCurveShape(EaseInCurve);
     }
 
 TimeLine::TimeLine(const TimeLine &other)
@@ -975,7 +996,7 @@ TimeLine::TimeLine(const TimeLine &other)
     m_Duration = other.m_Duration;
     m_TimeLine = new QTimeLine(m_Duration ? m_Duration : 1);
     m_TimeLine->setFrameRange(0, m_Duration);
-    setCurveShape(m_CurveShape);
+    setCurveShape(other.m_CurveShape);
     if( m_Duration != 0 )
         setProgress(m_Progress);
     }
@@ -1309,12 +1330,15 @@ QRectF WindowMotionManager::targetGeometry( EffectWindow *w ) const
 
 EffectWindow* WindowMotionManager::windowAtPoint( QPoint point, bool useStackingOrder ) const
     {
+    Q_UNUSED( useStackingOrder );
     // TODO: Stacking order uses EffectsHandler::stackingOrder() then filters by m_managedWindows
-    EffectWindowList windows = m_managedWindows.keys();
-
-    for( int i = 0; i < windows.size(); i++ )
-        if( transformedGeometry( windows.at( i )).contains( point ))
-            return windows.at( i );
+    QHash< EffectWindow*, WindowMotion >::ConstIterator it = m_managedWindows.constBegin();
+    while( it != m_managedWindows.constEnd() )
+        {
+        if( transformedGeometry( it.key() ).contains( point ) )
+            return it.key();
+        ++it;
+        }
 
     return NULL;
     }
