@@ -136,7 +136,7 @@ TabBoxClient* TabBoxHandlerImpl::clientToAddToList( TabBoxClient* client, int de
         Client* modal = current->findModal();
         if( modal == NULL || modal == current )
             ret = current;
-        else if( clientList().contains( modal->tabBoxClient() ) )
+        else if( !clientList().contains( modal->tabBoxClient() ) )
             ret = modal;
         else
             {
@@ -198,9 +198,9 @@ QString TabBoxClientImpl::caption() const
     return m_client->caption();
     }
 
-QPixmap TabBoxClientImpl::icon() const
+QPixmap TabBoxClientImpl::icon( const QSize& size ) const
     {
-    return m_client->icon();
+    return m_client->icon( size );
     }
 
 WId TabBoxClientImpl::window() const
