@@ -382,7 +382,7 @@ void Workspace::initAddToTabGroup()
 
 void Workspace::slotAddToTabGroup( QAction* action )
     {
-    if( !action->data().isValid() )
+    if( !action->data().isValid() || !active_popup_client->clientGroup() )
         return;
     moveItemToClientGroup( active_popup_client->clientGroup(),
         active_popup_client->clientGroup()->indexOfClient( active_popup_client ),
@@ -964,22 +964,28 @@ bool Client::performMouseCommand( Options::MouseCommand command, const QPoint &g
             break;
         case Options::MouseLeftGroupWindow:
             {
-            int c_id = clientGroup()->indexOfClient( this );
-            int size = clientGroup()->clients().count();
-            if( c_id > 0 )
-                clientGroup()->setVisible( c_id - 1 );
-            else
-                clientGroup()->setVisible( size - 1 );
+            if( clientGroup() ) 
+                {
+                int c_id = clientGroup()->indexOfClient( this );
+                int size = clientGroup()->clients().count();
+                if( c_id > 0 )
+                    clientGroup()->setVisible( c_id - 1 );
+                else
+                    clientGroup()->setVisible( size - 1 );
+	        }
             }
             break;
         case Options::MouseRightGroupWindow:
-            {
-            int c_id = clientGroup()->indexOfClient( this );
-            int size = clientGroup()->clients().count();
-            if( c_id < size - 1 )
-                clientGroup()->setVisible( c_id + 1 );
-            else
-                clientGroup()->setVisible( 0 );
+	    {
+            if( clientGroup() ) 
+                {
+                int c_id = clientGroup()->indexOfClient( this );
+                int size = clientGroup()->clients().count();
+                if( c_id < size - 1 )
+                    clientGroup()->setVisible( c_id + 1 );
+                else
+                    clientGroup()->setVisible( 0 );
+	        }
             }
             break;
         case Options::MouseClose:
