@@ -101,10 +101,8 @@ class ProgressBarItemDelegate : public QStyledItemDelegate
 
             //Now draw our percentage thingy
             const QRect &rect = option.rect;
-            int size = percentage * rect.width();
+            int size = qMin(percentage,1.0f) * rect.width();
             if(size > 2 ) { //make sure the line will have a width of more than 1 pixel
-                if(percentage > 1)
-                    percentage = 1;  //Don't draw outside our bounds
                 painter->setPen(Qt::NoPen);
                 QColor color = option.palette.color(cg, QPalette::Link);
                 color.setAlpha(50);
@@ -154,6 +152,7 @@ struct KSysGuardProcessListPrivate {
         : mModel(q, hostName), mFilterModel(q), mUi(new Ui::ProcessWidget()), mProcessContextMenu(NULL), mUpdateTimer(NULL)
     {
         mScripting = NULL;
+        mNeedToExpandInit = false;
         mNumItemsSelected = -1;
         mResortCountDown = 2; //The items added initially will be already sorted, but without CPU info.  On the second refresh we will have CPU usage, so /then/ we can resort
         renice = new KAction(i18np("Renice Process...", "Renice Processes...", 1), q);
@@ -222,6 +221,8 @@ struct KSysGuardProcessListPrivate {
     /** A counter to mark when to resort, so that we do not resort on every update */
     int mResortCountDown;
 
+    bool mNeedToExpandInit;
+
     KAction *renice;
     KAction *kill;
     KAction *selectParent;
@@ -354,11 +355,13 @@ void KSysGuardProcessList::setState(ProcessFilter::State state)
     d->mFilterModel.setFilter(state);
     d->mModel.setSimpleMode( (state != ProcessFilter::AllProcessesInTreeForm) );
     d->mUi->cmbFilter->setCurrentIndex( (int)state);
-    expandInit();
+    if(isVisible())
+        expandInit();
 }
 void KSysGuardProcessList::filterTextChanged(const QString &newText) {
     d->mFilterModel.setFilterRegExp(newText.trimmed());
-    expandInit();
+    if(isVisible())
+        expandInit();
     d->mUi->btnKillProcess->setEnabled( d->mUi->treeView->selectionModel()->hasSelection() );
     d->mUi->treeView->scrollTo( d->mUi->treeView->currentIndex());
 }
@@ -829,6 +832,7 @@ void KSysGuardProcessList::rowsInserted(const QModelIndex & parent, int start, i
                 expanded = true;
             }
             d->mUi->treeView->expand(index);
+            d->mNeedToExpandInit = true;
         }
     }
     if(expanded)
@@ -849,6 +853,7 @@ void KSysGuardProcessList::expandInit()
                 disconnect(d->mUi->treeView, SIGNAL(expanded(QModelIndex)), this, SLOT(expandAllChildren(QModelIndex)));
                 expanded = true;
             }
+
             d->mUi->treeView->expand(index);
         }
     }
@@ -916,6 +921,10 @@ void KSysGuardProcessList::updateList()
             QHeaderView *header= d->mUi->treeView->header();
             d->mUi->treeView->sortByColumn(header->sortIndicatorSection(), header->sortIndicatorOrder());
         }
+        if( d->mNeedToExpandInit ) {
+            expandInit();
+            d->mNeedToExpandInit = false;
+        }
     }
 }
 
