@@ -34,6 +34,9 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <QtDBus/QtDBus>
 #include <klocale.h>
 #include <kstringhandler.h>
+#ifndef WIN32
+#include <fixx11h.h>
+#endif
 #include <kstyle.h>
 #include <kwindowsystem.h>
 #include <netwm.h>
@@ -71,15 +74,16 @@ KWindowListMenu::~KWindowListMenu()
 
 static bool standaloneDialog( const KWindowInfo* info, const QList<KWindowInfo*>& list )
 {
+#ifndef Q_WS_WIN
   WId group = info->groupLeader();
 
   if ( group == 0 )
-    return info->transientFor() == QX11Info::appRootWindow();
+  return info->transientFor() == QX11Info::appRootWindow();
 
   foreach ( KWindowInfo* info, list )
     if ( info->groupLeader() == group )
       return false;
-
+#endif
   return true;
 }
 
@@ -189,7 +193,7 @@ void KWindowListMenu::slotForceActiveWindow()
     if (!window || !window->data().canConvert(QVariant::Int))
         return;
 
-    KWindowSystem::forceActiveWindow(window->data().toInt());
+    KWindowSystem::forceActiveWindow((WId)window->data().toInt());
 }
 
 void KWindowListMenu::slotSetCurrentDesktop()
