@@ -215,6 +215,7 @@ PlasmaApp::PlasmaApp()
       m_mainView(0),
       m_isDesktop(false),
       m_autoHideControlBar(true),
+      m_raiseTimer(new QTimer(this)),
       m_unHideTimer(0)
 {
     KGlobal::locale()->insertCatalog("libplasma");
@@ -246,16 +247,16 @@ PlasmaApp::PlasmaApp()
     Plasma::Theme::defaultTheme()->setFont(cg.readEntry("desktopFont", font()));
 
     m_mainView = new NetView(0, NetView::mainViewId(), 0);
+
+    m_raiseTimer->setSingleShot(true);
+    connect(m_raiseTimer, SIGNAL(timeout()), this, SLOT(raiseMainView()));
+	
     connect(m_mainView, SIGNAL(containmentActivated()), this, SLOT(mainContainmentActivated()));
     connect(KWindowSystem::self(), SIGNAL(workAreaChanged()), this, SLOT(positionPanel()));
     m_mainView->installEventFilter(this);
 
     connect(KWindowSystem::self(), SIGNAL(activeWindowChanged(WId)), this, SLOT(controlBarVisibilityUpdate()));
 
-    m_raiseTimer = new QTimer(this);
-    m_raiseTimer->setSingleShot(true);
-    connect(m_raiseTimer, SIGNAL(timeout()), this, SLOT(raiseMainView()));
-
     int width = 400;
     int height = 200;
     if (isDesktop) {
@@ -567,13 +568,14 @@ void PlasmaApp::createView(Plasma::Containment *containment)
 
     int id = viewIds.readEntry(QString::number(containment->id()), defaultId);
 
-    kDebug() << "new containment" << (QObject*)containment << containment->id()<<"view id"<<id;
+
+    kDebug() << "new containment" << (QObject*)containment << containment->id() << "view id" << id;
 
     //is it a desktop -and- is it active?
     if ((m_mainView && id == NetView::mainViewId()) ||
         (containment->containmentType() != Plasma::Containment::PanelContainment &&
          containment->containmentType() != Plasma::Containment::CustomPanelContainment &&
-         !viewIds.exists() && m_mainView->containment() == 0)) {
+         !viewIds.exists() && containment->screen() == 0)) {
         m_mainView->setContainment(containment);
         containment->setScreen(0);
     //is it a panel?
@@ -585,16 +587,6 @@ void PlasmaApp::createView(Plasma::Containment *containment)
             connect(screens, SIGNAL(screenResized(Kephal::Screen *, QSize, QSize)),
                     this, SLOT(adjustSize(Kephal::Screen *)));
 
-            m_controlBar->show();
-            KWindowSystem::setOnAllDesktops(m_controlBar->effectiveWinId(), true);
-            m_controlBar->setWindowFlags(m_mainView->windowFlags() | Qt::FramelessWindowHint);
-            m_controlBar->setFrameShape(QFrame::NoFrame);
-            unsigned long state = NET::Sticky | NET::StaysOnTop | NET::KeepAbove;
-            KWindowSystem::setState(m_controlBar->effectiveWinId(), state);
-            KWindowSystem::setType(m_controlBar->effectiveWinId(), NET::Dock);
-
-            m_controlBar->show();
-
             m_controlBar->setAutoFillBackground(false);
             m_controlBar->viewport()->setAutoFillBackground(false);
             m_controlBar->setAttribute(Qt::WA_TranslucentBackground);
@@ -606,6 +598,7 @@ void PlasmaApp::createView(Plasma::Containment *containment)
         }
 
         m_controlBar->setContainment(containment);
+        setControlBarVisible(true);
         containment->setMaximumSize(m_controlBar->size());
         containment->setMinimumSize(m_controlBar->size());
         containment->setImmutability(Plasma::UserImmutable);
@@ -697,7 +690,7 @@ void PlasmaApp::setAutoHideControlBar(bool autoHide)
         destroyUnHideTrigger();
         delete m_unHideTimer;
         m_unHideTimer = 0;
-        m_controlBar->show();
+        setControlBarVisible(true);
     }
 
     m_autoHideControlBar = autoHide;
@@ -731,7 +724,7 @@ void PlasmaApp::showWidgetExplorer(Plasma::Containment *containment)
         KWindowSystem::setOnAllDesktops(m_widgetExplorerView->winId(), true);
         m_widgetExplorerView->show();
         KWindowSystem::activateWindow(m_widgetExplorerView->winId());
-        m_widgetExplorerView->setWindowFlags(Qt::Dialog|Qt::FramelessWindowHint);
+        m_widgetExplorerView->setWindowFlags(Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint);
         m_widgetExplorerView->setAttribute(Qt::WA_TranslucentBackground);
         m_widgetExplorerView->setAttribute(Qt::WA_DeleteOnClose);
         KWindowSystem::setState(m_widgetExplorerView->winId(), NET::StaysOnTop|NET::KeepAbove);
@@ -829,7 +822,7 @@ bool PlasmaApp::eventFilter(QObject * watched, QEvent *event)
         destroyUnHideTrigger();
         if (m_controlBar) {
             Plasma::WindowEffects::slideWindow(m_controlBar, m_controlBar->location());
-            m_controlBar->show();
+            setControlBarVisible(true);
             m_raiseTimer->start(100);
             reserveStruts();
         }
@@ -852,7 +845,7 @@ kWarning()<<event;
         }
     } else if (watched == m_widgetExplorerView && event->type() == QEvent::Resize) {
          m_widgetExplorer->resize(m_widgetExplorerView->contentsRect().size());
-    } else if (watched == m_mainView && event->type() == QEvent::Close) {
+    } else if (!m_isDesktop && watched == m_mainView && event->type() == QEvent::Close) {
         exit();
     }
     return false;
@@ -912,7 +905,14 @@ void PlasmaApp::raiseMainView()
 
 void PlasmaApp::controlBarVisibilityUpdate()
 {
-    if (hasForegroundWindows() && m_controlBar->isVisible()) {
+    if (!m_controlBar) {
+        return;
+    }
+
+    if (!m_autoHideControlBar) {
+        setControlBarVisible(true);
+        return;
+    } else if (m_autoHideControlBar && hasForegroundWindows() && m_controlBar->isVisible()) {
         return;
     }
 
@@ -923,7 +923,7 @@ void PlasmaApp::controlBarVisibilityUpdate()
         if (!m_controlBar->isVisible()) {
             destroyUnHideTrigger();
             Plasma::WindowEffects::slideWindow(m_controlBar, m_controlBar->location());
-            m_controlBar->show();
+            setControlBarVisible(true);
         }
     } else if (!m_controlBar->geometry().contains(cursorPos)) {
         Plasma::WindowEffects::slideWindow(m_controlBar, m_controlBar->location());
@@ -944,11 +944,21 @@ void PlasmaApp::hideControlBar()
 
 void PlasmaApp::setControlBarVisible(bool visible)
 {
-   if (visible) {
+    if (!m_controlBar || m_controlBar->isVisible() == visible) {
+        return;
+    }
+
+    if (visible) {
         destroyUnHideTrigger();
         Plasma::WindowEffects::slideWindow(m_controlBar, m_controlBar->location());
         m_controlBar->show();
-    } else {
+        KWindowSystem::setOnAllDesktops(m_controlBar->effectiveWinId(), m_isDesktop);
+        m_controlBar->setWindowFlags(m_mainView->windowFlags() | Qt::FramelessWindowHint);
+        m_controlBar->setFrameShape(QFrame::NoFrame);
+        unsigned long state = NET::Sticky | NET::StaysOnTop | NET::KeepAbove;
+        KWindowSystem::setState(m_controlBar->effectiveWinId(), state);
+        KWindowSystem::setType(m_controlBar->effectiveWinId(), NET::Dock);
+    } else if (!m_autoHideControlBar) {
         Plasma::WindowEffects::slideWindow(m_controlBar, m_controlBar->location());
         m_controlBar->hide();
         createUnhideTrigger();
