@@ -18,17 +18,19 @@
  ***************************************************************************/
 
 #include "SettingsBase.h"
+#include "BaseConfig.h"
 
 #include <QTimer>
+#include <QRadioButton>
 #include <QVariantList>
 
 #include <KMenu>
 #include <KDebug>
-#include <KConfig>
 #include <KMenuBar>
 #include <KToolBar>
 #include <KAboutData>
 #include <KMessageBox>
+#include <KConfigGroup>
 #include <KCModuleInfo>
 #include <KXMLGUIFactory>
 #include <KStandardAction>
@@ -38,26 +40,27 @@
 #include "BaseData.h"
 #include "ModuleView.h"
 
-SettingsBase::SettingsBase( QWidget * parent ) :
-    KXmlGuiWindow(parent),
-    categories( KServiceTypeTrader::self()->query("SystemSettingsCategory") ),
-    modules( KServiceTypeTrader::self()->query("KCModule") )
+SettingsBase::SettingsBase( QWidget * parent )
+    : KXmlGuiWindow(parent)
 {
     // Ensure delayed loading doesn't cause a crash
     activeView = 0;
     aboutDialog = 0;
     configDialog = 0;
+    // Prepare the view area
+    stackedWidget = new QStackedWidget( this );
+    setCentralWidget(stackedWidget);
+    setWindowFlags( windowFlags() | Qt::WindowContextHelpButtonHint );
     // Initialise search
-    mainConfigGroup = KGlobal::config()->group( "Main" );
     searchText = new KLineEdit( this );
     searchText->setClearButtonShown( true );
     searchText->setClickMessage( i18nc( "Search through a list of control modules", "Search" ) );
+    searchText->setCompletionMode( KGlobalSettings::CompletionPopup );
 
     spacerWidget = new QWidget( this );
     spacerWidget->setSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Maximum );
     // Initalise the window so we don't flicker
     initToolBar();
-    showTooltips = mainConfigGroup.readEntry( "ShowTooltips", true );
     // We can now launch the delayed loading safely
     QTimer::singleShot(0, this, SLOT(initApplication()));
 }
@@ -69,17 +72,17 @@ SettingsBase::~SettingsBase()
 
 QSize SettingsBase::sizeHint() const
 {
-    return QSize(850, 650);
+    return QSize(720, 600);
 }
 
 void SettingsBase::initApplication()
 {
     // Prepare the menu of all modules
+    categories = KServiceTypeTrader::self()->query("SystemSettingsCategory");
+    modules = KServiceTypeTrader::self()->query("KCModule");
+    modules += KServiceTypeTrader::self()->query("SystemSettingsExternalApp");
     rootModule = new MenuItem( true, 0 );
     initMenuList(rootModule);
-    // Prepare the view area
-    stackedWidget = new QStackedWidget( this );
-    setCentralWidget(stackedWidget);
     // Prepare the Base Data
     BaseData::instance()->setMenuItem( rootModule );
     // Load all possible views
@@ -100,6 +103,8 @@ void SettingsBase::initApplication()
             kWarning() << "View load error: " + error;
         }
     }
+    searchText->completionObject()->setIgnoreCase( true );
+    searchText->completionObject()->setItems( BaseData::instance()->menuItem()->keywords() );
     changePlugin();
 }
 
@@ -110,6 +115,7 @@ void SettingsBase::initToolBar()
     actionCollection()->addAction( KStandardAction::Quit, "quit", this, SLOT( close() ) );
     // Configure goes at the end
     configureAction = actionCollection()->addAction( KStandardAction::Preferences, this, SLOT( configShow() ) );
+    configureAction->setShortcut(KShortcut(QKeySequence(Qt::CTRL + Qt::Key_M)));
     configureAction->setText( i18n("Configure") );
     // Help after it
     initHelpMenu();
@@ -148,16 +154,25 @@ void SettingsBase::initHelpMenu()
 void SettingsBase::initConfig()
 {
     // Prepare dialog first
-    configDialog = new KDialog(this);
+    configDialog = new KConfigDialog( this, "systemsettingsconfig", BaseConfig::self() );
     configDialog->setButtons( KDialog::Ok | KDialog::Cancel );
-    configWidget.setupUi(configDialog->mainWidget());
-    configDialog->setCaption(i18n("Configure"));
-    configDialog->setInitialSize(QSize(400,160));
-    configDialog->restoreDialogSize( KGlobal::config()->group("ConfigDialog") );
+
+    // Add our page
+    QWidget * configPage = new QWidget( configDialog );
+    configWidget.setupUi(configPage);
+    QString iconName = KGlobal::activeComponent().aboutData()->programIconName();
+    configDialog->addPage( configPage, i18nc("General config for System Settings", "General"), iconName );
+    QVBoxLayout * configLayout = new QVBoxLayout;
     // Get the list of modules
     foreach( BaseMode * mode, possibleViews ) {
-        configWidget.CbPlugins->addItem( KIcon(mode->service()->icon()), mode->service()->name() );
+        mode->addConfiguration( configDialog );
+        QRadioButton * radioButton = new QRadioButton( mode->service()->name(), configWidget.GbViewStyle );
+        radioButton->setIcon( KIcon(mode->service()->icon()) );
+        configLayout->addWidget( radioButton );
+        viewSelection.addButton( radioButton, possibleViews.values().indexOf(mode) );
     }
+    configWidget.GbViewStyle->setLayout( configLayout );
+    configDialog->restoreDialogSize( KGlobal::config()->group("ConfigDialog") );
     connect(configDialog, SIGNAL(okClicked()), this, SLOT(configUpdated()));
 }
 
@@ -168,7 +183,7 @@ void SettingsBase::initMenuList(MenuItem * parent)
     for (int i = 0; i < categories.size(); ++i) {
         const KService::Ptr entry = categories.at(i);
         const QString parentCategory = entry->property("X-KDE-System-Settings-Parent-Category").toString();
-        if ( parentCategory == parent->name() ) {
+        if ( parentCategory == parent->category() ) {
             MenuItem * menuItem = new MenuItem(true, parent);
             menuItem->setService( entry );
             initMenuList( menuItem );
@@ -179,7 +194,7 @@ void SettingsBase::initMenuList(MenuItem * parent)
     for (int i = 0; i < modules.size(); ++i) {
         const KService::Ptr entry = modules.at(i);
         const QString category = entry->property("X-KDE-System-Settings-Parent-Category").toString();
-        if(!parent->name().isEmpty() && category == parent->name() ) {
+        if( !parent->category().isEmpty() && category == parent->category() ) {
             // Add the module info to the menu
             MenuItem * infoItem = new MenuItem(false, parent);
             infoItem->setService( entry );
@@ -192,10 +207,9 @@ void SettingsBase::configUpdated()
 {
     KConfigGroup dialogConfig = KGlobal::config()->group("ConfigDialog");
     configDialog->saveDialogSize( dialogConfig );
-    const int currentIndex = configWidget.CbPlugins->currentIndex();
-    mainConfigGroup.writeEntry( "ActiveView", possibleViews.keys().at(currentIndex) );
-    showTooltips = configWidget.ChTooltips->isChecked();
-    mainConfigGroup.writeEntry( "ShowTooltips", showTooltips );
+    BaseConfig::setActiveView( possibleViews.keys().at(viewSelection.checkedId()) );
+    BaseConfig::setShowToolTips( configWidget.ChTooltips->isChecked() );
+    activeView->saveConfiguration();
     changePlugin();
 }
 
@@ -209,14 +223,14 @@ void SettingsBase::configShow()
         return; // It shouldn't be triggering anyway, since the action is disabled
     }
 
+    activeView->loadConfiguration();
+
     const QStringList pluginList = possibleViews.keys();
-    const int configIndex = pluginList.indexOf(mainConfigGroup.readEntry( "ActiveView", "icon_mode" ));
-    if( configIndex == -1 ) {
-        configWidget.CbPlugins->setCurrentIndex( 0 );
-    } else {
-        configWidget.CbPlugins->setCurrentIndex( configIndex );
+    const int configIndex = pluginList.indexOf( BaseConfig::activeView() );
+    if( configIndex != -1 ) {
+        viewSelection.button( configIndex )->setChecked(true);
     }
-    configWidget.ChTooltips->setChecked( showTooltips );
+    configWidget.ChTooltips->setChecked( BaseConfig::showToolTips() );
     if( pluginList.isEmpty() ) {
         KMessageBox::error(this, i18n("System Settings was unable to find any views, and hence nothing is available to configure."), i18n("No views found"));
     } else {
@@ -231,7 +245,7 @@ bool SettingsBase::queryClose()
         activeView->saveState();
         changes = activeView->moduleView()->resolveChanges();
     }
-    mainConfigGroup.sync();
+    BaseConfig::self()->writeConfig();
     return changes;
 }
 
@@ -267,7 +281,7 @@ void SettingsBase::changePlugin()
         activeView->leaveModuleView();
     }
 
-    const QString viewToUse = mainConfigGroup.readEntry( "ActiveView", "icon_mode" );
+    const QString viewToUse = BaseConfig::activeView();
     if( possibleViews.keys().contains(viewToUse) ) { // First the configuration entry
         activeView = possibleViews.value(viewToUse);
     }
@@ -279,13 +293,23 @@ void SettingsBase::changePlugin()
         stackedWidget->addWidget(activeView->mainWidget());
     }
 
+    // Handle the tooltips
+    qDeleteAll( tooltipManagers );
+    tooltipManagers.clear();
+    if ( BaseConfig::showToolTips() ) {
+        QList<QAbstractItemView*> theViews = activeView->views();
+        foreach ( QAbstractItemView* view, theViews ) {
+            tooltipManagers << new ToolTipManager( view );
+        }
+    }
+
     changeAboutMenu( activeView->aboutData(), aboutViewAction, i18n("About Active View") );
     viewChange(false);
-    activeView->setEnhancedTooltipEnabled( showTooltips );
+
     stackedWidget->setCurrentWidget(activeView->mainWidget());
     updateViewActions();
 
-    activeView->mainWidget()->setFocus();
+    activeView->giveFocus();
 }
 
 void SettingsBase::viewChange(bool state)
